// **************************************************************************
// hpvm_public_example.c - Test the public APIs in libhpvmguest.so
//
// Description:  This is an example C program that utilizes all 
//		 the supported HPVM APIs defined in hpvm_api_public.h
//		 and contained in the libhpvmguest shared library.
//
// To compile 32 bit:
//     cc +DD32 -DIA -o hpvm_public_example32 hpvm_public_example.c \
//         -I /opt/hpvm/include -L /opt/hpvm/lib/hpux32 -lhpvmguest
//
// To compile 64 bit:
//     cc +DD64 -DIA -o hpvm_public_example64 hpvm_public_example.c \
//         -I /opt/hpvm/include -L /opt/hpvm/lib/hpux64 -lhpvmguest
//
// To compile on REDHAT LINUX:
//     cc -DREDHAT -o hpvm_public_example hpvm_public_example.c \
//         -I /opt/hpvm/include -L/opt/hpvm/lib -lhpvmguest
//
// To compile on SUSE LINUX:
//     cc -DSUSE -o hpvm_public_example hpvm_public_example.c \
//         -I /opt/hpvm/include -L/opt/hpvm/lib -lhpvmguest
//
// On Windows use Visual Studio to compile hpvm_public_example.c.
// NOTE: Since Windows no longer supports a development environment on
//       IA64 this program and libhpvmguest will need to be copied 
//       to a 32bit Windows system running Visual Studio.
//
// **************************************************************************

#ifdef WIN32
#include <windows.h>
#endif

#ifdef REDHAT
#include <idn-int.h>
#endif

#ifdef SUSE
#include <stdint.h>
#endif

#include <stdio.h>
#include <string.h>
#include "hpvm_api_public.h"

main(void)
// Test public routines
{
    HPVM_int    retcode;
    char        version[HPVMAPIDEFMEMSIZ];
    char        myuuid[HPVMAPIDEFMEMSIZ];
    char        myident[HPVMAPIDEFMEMSIZ];
    char        svruuid[HPVMAPIDEFMEMSIZ];
    char        svrident[HPVMAPIDEFMEMSIZ];
    char        svrhname[HPVMAPIDEFMEMSIZ];

    memset(myuuid,0,HPVMAPIDEFMEMSIZ);
    memset(myident,0,HPVMAPIDEFMEMSIZ);
    memset(svruuid,0,HPVMAPIDEFMEMSIZ);
    memset(svrident,0,HPVMAPIDEFMEMSIZ);
    memset(svrhname,0,HPVMAPIDEFMEMSIZ);
    memset(version,0,HPVMAPIDEFMEMSIZ);

    // Get the HPVM version string
    retcode = hpvm_api_version_get(version);
    if ((retcode != 0) || (strlen(version) < 10)) {
        fprintf(stderr,"ERROR: hpvm_api_version_get() failed: error %d.\n",
                retcode);
    }
    // Get the uuid of this system
    retcode = hpvm_api_my_uuid_get(myuuid);
    if ((retcode != 0) || (strlen(myuuid) != (HPVMAPI_UUIDLEN-1))) {
        fprintf(stderr,"ERROR: hpvm_api_my_uuid_get() failed: error %d.\n",
                retcode);
    }
    // Get the physical identifier of this system
    retcode = hpvm_api_my_physident_get(myident);
    if ((retcode != 0) || (strlen(myident) < (HPVMAPI_UUIDLEN-1))) {
        fprintf(stderr,"ERROR: hpvm_api_my_physident_get() failed: error %d.\n",
                retcode);
    }
    // Check if this is an HPVM server
    if (hpvm_api_server_check() == HPVM_TRUE) {
	// Check if this is a virtual machine - it cannot be both
        if (hpvm_api_virtmach_check() != HPVM_FALSE) {
            fprintf(stderr,"ERROR: hpvm_api_virtmach_check() failed: with TRUE.\n");
        }
	// Get the HPVM server uuid 
        retcode = hpvm_api_server_uuid_get(svruuid);
	// Expect error - this is not a virtual machine
        if (retcode != HPVMAPINOTVM) {
            fprintf(stderr,"ERROR: hpvm_api_server_uuid_get() failed: error %d.\n", 
		    retcode);
        }
	// Get the HPVM server physical identifier 
	retcode = hpvm_api_server_physident_get(svrident);
	// Expect error - this is not a virtual machine
	if (retcode != HPVMAPINOTVM) {
	    fprintf(stderr,"ERROR: hpvm_api_server_physident_get() failed: error %d.\n",
		    retcode);
        }
	// Get the HPVM server hostname of this virtual machine
        retcode = hpvm_api_server_hostname_get(svrhname);
	// Expect error - this is not a virtual machine
        if (retcode != HPVMAPINOTVM) {
            fprintf(stderr,"ERROR: hpvm_api_server_hostname_get() failed: error %d.\n", 
		    retcode);
        }
    } else {
	// Check if this is a virtual machine - It must be  
        if (hpvm_api_virtmach_check() != HPVM_TRUE) {
            fprintf(stderr,"ERROR: hpvm_api_virtmach_check() failed: with FALSE.\
n");
        }
	// Get the HPVM server uuid of this virtual machine
        retcode = hpvm_api_server_uuid_get(svruuid);
        if ((retcode != 0) || (strlen(svruuid) != (HPVMAPI_UUIDLEN-1))) {
            fprintf(stderr,"ERROR: hpvm_api_server_uuid_get() failed: error %d.\n",
                    retcode);
        }
	// Get the HPVM server physical identifier 
	retcode = hpvm_api_server_physident_get(svrident);
        if ((retcode != 0) || (strlen(svrident) < (HPVMAPI_UUIDLEN-1))) {
            fprintf(stderr,"ERROR: hpvm_api_server_physident_get() failed: error %d.\n",
                    retcode);
        }
	// Get the HPVM server hostname of this virtual machine
        retcode = hpvm_api_server_hostname_get(svrhname);
        if (retcode != 0) {
            fprintf(stderr,"ERROR: hpvm_api_server_hostname_get() failed: error %d.\n",
                    retcode);
        }
    }
    // Print the HPVM version
    if (strlen(version) > 1) {
        fprintf(stdout,"HPVM Version = %s\n",version);
    }
    // Print the uuid for this system
    if (strlen(myuuid) > 1) {
        fprintf(stdout,"My uuid = %s\n",myuuid);
    }
    // Print the physical identifier for this system
    if (strlen(myident) > 1) {
	fprintf(stdout,"My identifier = %s\n",myident);
    }
    // Print the HPVM server uuid for this virtual machine
    if (strlen(svruuid) > 1) {
        fprintf(stdout,"HPVM servers uuid = %s\n",svruuid);
    }
    // Print the HPVM server indentifer 
    if (strlen(svrident) > 1) {
	fprintf(stdout,"HPVM servers identifier  = %s\n",svrident);
    }
    // Print the HPVM server hostname for this virtual machine
    if (strlen(svrhname) > 1) { 
        fprintf(stdout,"HPVM servers hostname = %s\n",svrhname);
    }
    return 0;
}
