// **********************************************************************
//   (C) Copyright 2004-2008 Hewlett-Packard Development Company, L.P.
//   HPVM: $Id: hpvm_api_public.h 6011 2007-03-09 18:46:35 - HP CONFIDENTIAL
// **********************************************************************
#ifndef HPVM_API_PUBLIC_H
#define HPVM_API_PUBLIC_H
// =======================================================================
//  HP IA-64 Virtual Machine: hpvm_api_public.h
// =======================================================================
//
//   File Description: Interface to public HPVM functions provided by
//   libhpvm to HPVM server based applications and libhpvmguest to 
//   virtual machine based applications.	
//
//   MEMORY ALLOCATION
//   Preallocated memory must be provided by the caller for all functions 
//   that return strings or structures. The preallocated memory region 
//   must be at least 256 characters long or HPVMAPIDEFMEMSIZ.
//
// =======================================================================
//
// Definitions for basic data types assuming no access to inttypes.h
// typedefs used for the interfaces defined in this header
typedef char	  HPVM_char;
typedef char      *HPVM_str;
typedef unsigned int  HPVM_boolean;
typedef int           HPVM_int;
typedef unsigned int  HPVM_uint;

#ifndef NULL
#define NULL      (0)
#endif // NULL

#ifndef TRUE
#define TRUE 	1
#endif // TRUE
#ifndef FALSE
#define FALSE	(!TRUE)
#endif // FALSE

// Return values for boolean functions
#define HPVM_TRUE 	( (HPVM_boolean) TRUE )
#define HPVM_FALSE	( (HPVM_boolean) FALSE )

// Default memory for returned strings or structures
#define	HPVMAPIDEFMEMSIZ	256

// Size of a UUID string
#define	HPVMAPI_UUIDLEN	37

// specific hpvm public api integer return values
#define HPVMAPISUCCESS     0       // success return value  	(EHPVMOK)
#define HPVMAPISECFAIL     1       // Security check failed 	(EHPVMPERM)
#define HPVMAPINOMEMORY    12      // No memory			(EHPVMNOMEM )
#define HPVMAPIINVALARG    22      // Invalid argument      	(EHPVMINVAL)
#define HPVMAPIIOERROR     93      // I/O error			(EHPVMIO)
#define HPVMAPINOSVRINFO   101	   // Cannot get HPVM server info (EHPVMNOSVRINFO)
#define HPVMAPINOTVM	   129     // Not running on a virtual machine (EHPVMNOTINVM)
#define HPVMAPIBADFORMAT   130	   // Bad format		(EHPVMBADFORMAT)
#define HPVMAPINOTSUP      251	   // Routine not supported     (EHPVMNOSYS)

// =======================================================================
// boolean routine to check if running on an hpvm server (host)

extern HPVM_boolean hpvm_api_server_check(void);

// =======================================================================
// boolean routine to check if running on an hpvm virtual machine (guest)

extern HPVM_boolean hpvm_api_virtmach_check(void);

// =======================================================================
// Routine to get the HPVM version for (host or guest)
//
// Inputs:
// A pointer to a string of size greater than or equal to
// 256 characters must be passed in. 
//
// Return values:
// Return value of zero => success
// On error the return value will be set to one
// of the error return values listed in this header file

extern HPVM_int hpvm_api_version_get(HPVM_str);

// ===============================================================
// Routine to get the HPVM uuid of this machine (host or guest)
//
// Inputs:
// A pointer to a string of size greater than or equal to
// 256 characters must be passed in. 
//
// Return values:
// zero => success
// On error the return value will be set to one
// of the error return values listed in this header file

extern HPVM_int  hpvm_api_my_uuid_get(HPVM_str);

// ===============================================================
// Routine to get the HPVM physical identifier (host or guest)
//
// Inputs:
// A pointer to a string of size greater than or equal to
// 256 characters must be passed in. 
//
// Return values:
// zero => success
// On error the return value will be set to one
// of the error return values listed in this header file

extern HPVM_int  hpvm_api_my_physident_get(HPVM_str);

// ===============================================================
// Routine gets the HPVM server uuid for this virtual machine 
//	(Will return an error if run on the HPVM server)
// Inputs:
// A pointer to a string of size greater than or equal to
// 256 characters must be passed in. 
//
// Return values:
// zero => success
// On error the return value will be set to one
// of the error return values listed in this header file

extern HPVM_int  hpvm_api_server_uuid_get(HPVM_str);

// ===============================================================
// Routine gets the HPVM server physical identifier this virtual machine 
//	(Will return an error if run on the HPVM server)
// Inputs:
// A pointer to a string of size greater than or equal to
// 256 characters must be passed in. 
//
// Return values:
// zero => success
// On error the return value will be set to one
// of the error return values listed in this header file

extern HPVM_int  hpvm_api_server_physident_get(HPVM_str);

// ==============================================================
// Routine gets the HPVM server hostname for this virtual machine
//	(Will return an error if run on the HPVM server)
// Inputs:
// A pointer to a string of size greater than or equal to
// 256 characters must be passed in. 
//
// Return values:
// zero => success
// On error the return value will be set to one
// of the error return values listed in this header file

extern HPVM_int  hpvm_api_server_hostname_get(HPVM_str);

#endif // HPVM_API_PUBLIC_H 
